/* 
 * Copyright (c) 2007, Fraunhofer-Gesellschaft
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 * (1) Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the disclaimer at the end.
 *     Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 * 
 * (2) Neither the name of Fraunhofer nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *  
 */
package org.ogf.graap.wsag.client.api;

import javax.security.auth.login.LoginContext;

import org.w3.x2005.x08.addressing.EndpointReferenceType;

/**
 * Factory interface for wsag4j clients.
 * 
 * @param <T>
 *            the client type
 * 
 * @author Oliver Waeldrich
 * 
 */
public interface ClientFactory<T>
{
    /**
     * location of the default configuration file
     */
    String DEFAULT_CONFIGURATION_FILE = "/org.ogf.graap.wsag.client.api.ClientFactory.properties";

    /**
     * Creates a new client for a given endpoint. This method can only be used when server side security is
     * disabled.
     * 
     * @param epr
     *            the factory registry endpoint
     * 
     * @return the factory registry client
     * 
     * @throws Exception
     *             the instantiation of the registry implementation failed
     */
    T newInstance( EndpointReferenceType epr ) throws Exception;

    /**
     * Creates a new client for a given endpoint using the given login context. This method is used when
     * server side security is enabled (default).
     * 
     * @param epr
     *            the factory registry endpoint
     * 
     * @param context
     *            the login context to use
     * 
     * @return the factory registry client
     * 
     * @throws Exception
     *             the instantiation of the registry implementation failed
     */
    T newInstance( EndpointReferenceType epr, LoginContext context ) throws Exception;

}
