/* 
 * Copyright (c) 2012, Fraunhofer-Gesellschaft
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 * (1) Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the disclaimer at the end.
 *     Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 * 
 * (2) Neither the name of Fraunhofer nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *  
 */
package org.ogf.graap.wsag.client.api.impl;

import java.util.Properties;

import org.ogf.graap.wsag.api.security.ISecurityProperties;
import org.ogf.graap.wsag.client.api.RemoteClient;
import org.w3.x2005.x08.addressing.EndpointReferenceType;

/**
 * @author owaeld
 * 
 */
public abstract class AbstractClient
{
    /**
     * 
     */
    public AbstractClient()
    {
        super();
    }

    /**
     * Returns the remote reference of the remote client. Remote references are encapsulated as endpoint
     * references.
     * 
     * @return the remote reference
     */
    public EndpointReferenceType getRemoteReference()
    {
        return getRemoteClient().getRemoteReference();
    }

    /**
     * Returns the remote client used by this implementation in order to communicate with the WSAG4J server.
     * 
     * @return the remote client
     */
    public abstract RemoteClient getRemoteClient();

    /**
     * Returns the properties of the remote client.
     * 
     * @return the remote client properties
     */
    public Properties getProperties()
    {
        return getRemoteClient().getProperties();
    }

    /**
     * Sets the properties for the remote client.
     * 
     * @param properties
     *            the remote client properties
     */
    public void setProperties( Properties properties )
    {
        getRemoteClient().setProperties( properties );
    }

    /**
     * Returns whether or not the remote client traces the messages to the console.
     * 
     * @return trace mode enabled
     */
    public boolean isUsingTrace()
    {
        return getRemoteClient().isUsingTrace();
    }

    /**
     * Sets whether or not the remote client traces the messages to the console.
     * 
     * @param trace
     *            trace mode
     */
    public void setTrace( boolean trace )
    {
        getRemoteClient().setTrace( trace );
    }

    /**
     * Returns the security properties of the remote client.
     * 
     * @return the security properties for this client
     */
    public ISecurityProperties getSecurityProperties()
    {
        return getRemoteClient().getSecurityProperties();
    }

}