/* 
 * Copyright (c) 2007, Fraunhofer-Gesellschaft
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 * (1) Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the disclaimer at the end.
 *     Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 * 
 * (2) Neither the name of Fraunhofer nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *  
 */
package org.ogf.graap.wsag.client.api.impl;

import org.ogf.graap.wsag.api.exceptions.NegotiationException;
import org.ogf.graap.wsag.api.exceptions.ResourceUnavailableException;
import org.ogf.graap.wsag.api.exceptions.ResourceUnknownException;
import org.ogf.graap.wsag.client.api.NegotiationClient;
import org.ogf.schemas.graap.wsAgreement.AgreementTemplateType;
import org.ogf.schemas.graap.wsAgreement.negotiation.NegotiationContextType;
import org.ogf.schemas.graap.wsAgreement.negotiation.NegotiationOfferType;

/**
 * Default implementation of a negotiation client. Concrete implementations must provide a proper
 * implementation of the server interaction.
 * 
 * @author hrasheed
 */
public abstract class NegotiationClientImpl extends AbstractClient
    implements NegotiationClient
{

    /**
     * {@inheritDoc}
     */
    public abstract NegotiationContextType getNegotiationContext()
        throws ResourceUnknownException, ResourceUnavailableException;

    /**
     * {@inheritDoc}
     */
    public abstract AgreementTemplateType[] getNegotiableTemplates()
        throws ResourceUnknownException, ResourceUnavailableException;

    /**
     * {@inheritDoc}
     */
    public abstract NegotiationOfferType[] getNegotiationOffers()
        throws ResourceUnknownException, ResourceUnavailableException;

    /**
     * {@inheritDoc}
     */
    public abstract NegotiationOfferType[] negotiate( NegotiationOfferType[] quotes )
        throws NegotiationException, ResourceUnknownException, ResourceUnavailableException;

    /**
     * {@inheritDoc}
     */
    public abstract void advertise( NegotiationOfferType[] quotes )
        throws NegotiationException, ResourceUnknownException, ResourceUnavailableException;

    /**
     * {@inheritDoc}
     */
    public NegotiationOfferType getNegotiationOffer( String offerID )
        throws ResourceUnknownException, ResourceUnavailableException
    {
        NegotiationOfferType[] offers = getNegotiationOffers();
        for ( int i = 0; i < offers.length; i++ )
        {
            NegotiationOfferType offer = offers[i];
            if ( offerID.equals( offer.getOfferId() ) )
            {
                return offer;
            }
        }

        throw new ResourceUnavailableException( "no negotiationoffer found for offer id: " + offerID );
    }

    /**
     * {@inheritDoc}
     */
    public abstract void terminate() throws ResourceUnknownException, ResourceUnavailableException;

    /**
     * {@inheritDoc}
     */
    public abstract void destroy() throws ResourceUnknownException, ResourceUnavailableException;

    /**
     * {@inheritDoc}
     */
    @Override
    public abstract NegotiationClient clone() throws CloneNotSupportedException;
}
