/* 
 * Copyright (c) 2007, Fraunhofer-Gesellschaft
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 * (1) Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the disclaimer at the end.
 *     Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 * 
 * (2) Neither the name of Fraunhofer nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *  
 */
package org.ogf.graap.wsag.client.api.local;

import org.apache.xmlbeans.XmlObject;
import org.ogf.graap.wsag.api.Negotiation;
import org.ogf.graap.wsag.api.exceptions.NegotiationException;
import org.ogf.graap.wsag.api.exceptions.ResourceUnavailableException;
import org.ogf.graap.wsag.api.exceptions.ResourceUnknownException;
import org.ogf.graap.wsag.client.api.NegotiationClient;
import org.ogf.graap.wsag.client.api.RemoteClient;
import org.ogf.graap.wsag.client.api.impl.NegotiationClientImpl;
import org.ogf.schemas.graap.wsAgreement.AgreementTemplateType;
import org.ogf.schemas.graap.wsAgreement.negotiation.NegotiationContextType;
import org.ogf.schemas.graap.wsAgreement.negotiation.NegotiationOfferType;

/**
 * Default implementation of a negotiation client for local access to a negotiation instance. Internal use
 * only.
 * 
 * @author hrasheed
 * 
 */
public class LocalNegotiationClient extends NegotiationClientImpl
{

    private final Negotiation negotiation;

    private RemoteClient wsclient = new LocalWsClient();

    /**
     * 
     * @param negotiation
     *            the negotiation instance
     */
    public LocalNegotiationClient( Negotiation negotiation )
    {
        this.negotiation = negotiation;
        wsclient = new LocalWsClient();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public NegotiationClient clone() throws CloneNotSupportedException
    {
        return new LocalNegotiationClient( negotiation );
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public RemoteClient getRemoteClient()
    {
        return wsclient;
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.ogf.graap.wsag.client.impl.NegotiationClientImpl#getNegotiationContext()
     */
    @Override
    public NegotiationContextType getNegotiationContext()
        throws ResourceUnknownException, ResourceUnavailableException
    {
        return negotiation.getNegotiationContext();
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.ogf.graap.wsag.client.impl.NegotiationClientImpl#getNegotiableTemplates()
     */
    @Override
    public AgreementTemplateType[] getNegotiableTemplates()
        throws ResourceUnknownException, ResourceUnavailableException
    {
        return negotiation.getNegotiableTemplates();
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.ogf.graap.wsag.client.impl.NegotiationClientImpl#getNegotiationOffers()
     */
    @Override
    public NegotiationOfferType[] getNegotiationOffers()
        throws ResourceUnknownException, ResourceUnavailableException
    {
        return negotiation.getNegotiationOffers();
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.ogf.graap.wsag.client.impl.NegotiationClientImpl#negotiate(org.ogf.schemas.graap.wsAgreement.
     * negotiation.NegotiationOfferType[])
     */
    @Override
    public NegotiationOfferType[] negotiate( NegotiationOfferType[] quotes )
        throws NegotiationException, ResourceUnknownException, ResourceUnavailableException
    {
        return negotiation.negotiate( quotes, new XmlObject[0] );
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.ogf.graap.wsag.client.impl.NegotiationClientImpl#advertise(org.ogf.schemas.graap.wsAgreement.
     * negotiation.NegotiationOfferType[])
     */
    @Override
    public void advertise( NegotiationOfferType[] quotes )
        throws NegotiationException, ResourceUnknownException, ResourceUnavailableException
    {
        negotiation.advertise( quotes, new XmlObject[0] );
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.ogf.graap.wsag.client.impl.NegotiationClientImpl#terminate()
     */
    @Override
    public void terminate() throws ResourceUnknownException, ResourceUnavailableException
    {
        negotiation.terminate();
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.ogf.graap.wsag.client.impl.NegotiationClientImpl#destroy()
     */
    @Override
    public void destroy() throws ResourceUnknownException, ResourceUnavailableException
    {
        // nothing to do
    }

}
